@@ -47,7 +47,7 @@ class Application(GtkWindow):
 			('Python/Profile...', None, self.python_prof),
 			('Help/About...', None, self.help_about),
 		])
-		self.add_accelerator_table(mf.accelerator)
+		self.add_accel_group(mf.accelerator)
 		hdlbox.add(mf)
 		mf.show()
 		self.mf = mf
