@@ -1,4 +1,4 @@
-#!/usr/bin/python
+#!/usr/bin/env python
 #
 # Tests of python-gtk.
 #
@@ -63,7 +63,7 @@ class Application:
 
                         ('Help/About', None, self.process_help_about)
                 ])
-		self.w_window.add_accelerator_table(self.w_menubar.accelerator)
+		self.w_window.add_accel_group(self.w_menubar.accelerator)
 		self.w_vbox.pack_start(self.w_menubar, expand=FALSE)
 		self.w_menubar.show()
 		
